use std::process::Command;

#[cfg(all(target_arch = "x86_64", target_os = "linux", target_env = "gnu"))]
static EXPECTED: &str = r#"arch: x86_64
os: linux
family: unix
env: gnu
endian: little
pointer_width: 64
vendor: unknown
feature: ["fxsr", "sse", "sse2"]
"#;

#[cfg(all(target_arch = "x86_64", target_os = "windows", target_env = "msvc"))]
static EXPECTED: &str = r#"arch: x86_64
os: windows
family: windows
env: msvc
endian: little
pointer_width: 64
vendor: pc
feature: ["fxsr", "sse", "sse2"]
"#;

#[cfg(all(target_arch = "x86_64", target_os = "macos", target_env = ""))]
static EXPECTED: &str = r#"arch: x86_64
os: macos
family: unix
env: 
endian: little
pointer_width: 64
vendor: apple
feature: ["fxsr", "sse", "sse2", "sse3", "ssse3"]
"#;

#[cfg(all(target_arch = "aarch64", target_os = "macos", target_env = ""))]
static EXPECTED: &str = r#"arch: aarch64
os: macos
family: unix
env: 
endian: little
pointer_width: 64
vendor: apple
feature: []
"#;

#[test]
fn binary_output() {
  let output = format!(r#"arch: {}
os: {}
family: {}
env: {}
endian: {}
pointer_width: {}
vendor: {}
feature: {:?}
"#, target::arch(), target::os(), target::family(), target::env(), target::endian(), target::pointer_width(), target::vendor(), target::features());
  pretty_assertions::assert_eq!(output, EXPECTED);
}
